==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-leave/lxqt-leave_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../../../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Odejít</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="59"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Co po počítači chcete, aby udělal?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="92"/>
        <source>Logout</source>
        <translation>Odhlásit se</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="206"/>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="186"/>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="139"/>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="112"/>
        <source>Lock screen</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="159"/>
        <source>Hibernate</source>
        <translation>Přezimovat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="42"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation>Odhlásit se.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation>Uzamknout obrazovku.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation>Uspat.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation>Přezimovat (hibernace).</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation>Vypnout.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation>Restartovat.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-leave/lxqt-leave_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../../../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Odejít</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Co po počítači chcete, aby udělal?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Odhlásit se</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Přezimovat</translation>
    </message>
    <message>
        <location filename="../../../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Odhlásit se.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Uzamknout obrazovku.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Uspat.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Přezimovat (hibernace).</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Vypnout.</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Restartovat.</translation>
    </message>
</context>
</TS>
